#! /bin/tcsh -f
#
#   demonstration of relative indexing success
#
#
if( 0 ) then 
cd ~/projects/bugreports/dials_index
source ~/projects/cctbx-dev/build/setpaths.csh 
endif

rm -f cells.txt
foreach seed ( `cat bad_*_scores.txt` )

libtbx.python ./tst_nanoBragg_forindex.py random $seed >! simtbx_${seed}.log

./autoindex.com | log_timestamp.tcl | tee mosflm.log |\
 awk '/Final cell/{print $(NF-5),$(NF-4),$(NF-3),$(NF-2),$(NF-1),$(NF)}' >! cell.txt
set mosflm_cell = `cat cell.txt`
if($#mosflm_cell != 6) set mosflm_cell = ( - - - - - - )

xds_par |& log_timestamp.tcl | tee xds.log |\
awk '/UNIT CELL PARAM/{print $(NF-5),$(NF-4),$(NF-3),$(NF-2),$(NF-1),$(NF)}' >! cell.txt
set xds_cell = `cat cell.txt`
if($#xds_cell != 6) set xds_cell = ( - - - - - - )

dials.stills_process noiseimage_001.cbf dials.phil |&\
  log_timestamp.tcl | tee dials.log |\
egrep -v max_cell |\
awk '/cell:/{gsub("cell: \\(","");print $(NF-5),$(NF-4),$(NF-3),$(NF-2),$(NF-1),$(NF)}' |\
tail -n 1 >! cell.txt
set dials_cell = `cat cell.txt`
if($#dials_cell != 6) set dials_cell = ( - - - - - - )

echo "$seed $mosflm_cell     $xds_cell     $dials_cell" | tee -a cells.txt

set mosflm_time = `tail -n 1 mosflm.log | awk '{print $8}'`
set xds_time = `tail -n 1 xds.log | awk '{print $8}'`
set dials_time = `tail -n 1 dials.log | awk '{print $8}'`

echo "$seed $mosflm_time $xds_time $dials_time" | tee -a times.txt

end

cat cells.txt |\
awk '{++n;mos_rmse=mos_rmsa=dia_rmse=dia_rmsa="n/d"\
      dials_fail = ( $19+0 == 0 );\
      xds_fail = ( $13+0 == 0 );\
      mosflm_fail = ( $7+0 == 0 );\
      if(! mosflm_fail){\
          ++mosflm_hits;\
          mos_rmse=sqrt(($2-50)**2+($3-60)**2+($4-70)**2);\
          mos_rmsa=sqrt(($5-90)**2+($6-90)**2+($7-90)**2);\
      }\
      if(! xds_fail){\
          ++xds_hits;\
          xds_rmse=sqrt(($8-50)**2+($9-60)**2+($10-70)**2);\
          xds_rmsa=sqrt(($11-90)**2+($12-90)**2+($13-90)**2);\
      }\
      if(! dials_fail){\
          ++dials_hits;\
          dia_rmse=sqrt(($14-50)**2+($15-60)**2+($16-70)**2);\
          dia_rmsa=sqrt(($17-90)**2+($18-90)**2+($19-90)**2);\
      }\
      print $1,mosflm_fail,xds_fail,dials_fail,\
         mos_rmse,mos_rmsa,xds_rmse,xds_rmsa,dia_rmse,dia_rmsa}' |\
awk '{print $5+$6+$7+$8+$9+$10,$0}' | sort -g |\
awk '{$1="";print}' |\
tee scores.txt

cat scores.txt |\
awk '{++n;\
      mosflm_fail+=$2;xds_fail=$3;dials_fail+=$4;\
      mosflm_sumde+=$4*$4;mosflm_sumda+=$5*$5;\
      dials_sumde+=$6*$6;dials_sumda+=$7*$7}\
      dials_sumde+=$6*$6;dials_sumda+=$7*$7}\
     END{mosflm_hits=n-mosflm_fail;dials_hits=n-dials_fail;\
          print mosflm_hits/n,dials_hits/n,\
          sqrt(mosflm_sumde/mosflm_hits),sqrt(mosflm_sumda/mosflm_hits),\
          sqrt(dials_sumde/dials_hits),sqrt(dials_sumda/dials_hits)}'

rm -f medians.txt
awk '{print $5}' scores.txt | awk '$1+0>0' | ~/awk/median.awk | tee -a medians.txt
awk '{print $6}' scores.txt | awk '$1+0>0' | ~/awk/median.awk | tee -a medians.txt
awk '{print $7}' scores.txt | awk '$1+0>0' | ~/awk/median.awk | tee -a medians.txt
awk '{print $8}' scores.txt | awk '$1+0>0' | ~/awk/median.awk | tee -a medians.txt
awk '{print $9}' scores.txt | awk '$1+0>0' | ~/awk/median.awk | tee -a medians.txt
awk '{print $10}' scores.txt | awk '$1+0>0' | ~/awk/median.awk | tee -a medians.txt

awk '{print $5}' scores.txt | ~/awk/histogram.awk -v bs=0.5 | tee hist_mos_edge.txt
awk '{print $6}' scores.txt | ~/awk/histogram.awk -v bs=0.5 | tee hist_mos_angle.txt
awk '{print $7}' scores.txt | ~/awk/histogram.awk -v bs=0.5 | tee hist_xds_edge.txt
awk '{print $8}' scores.txt | ~/awk/histogram.awk -v bs=0.5 | tee hist_xds_angle.txt
awk '{print $9}' scores.txt | ~/awk/histogram.awk -v bs=0.5 | tee hist_dia_edge.txt
awk '{print $10}' scores.txt | ~/awk/histogram.awk -v bs=0.5 | tee hist_dia_angle.txt


awk '$4==1 || $9>1 || $10>1{print $1}' scores.txt | tee bad_dials_seeds.txt
awk '$3==1 || $7>1 || $8>1{print $1}' scores.txt | tee bad_xds_seeds.txt
awk '$2==1 || $5>1 || $6>1{print $1}' scores.txt | tee bad_mosflm_seeds.txt




tar czvf ~/html/bugreports/dials_index_020418.tgz \
 runme.com autoindex.com tst_nanoBragg_forindex.py \
 ipmosflm lib* cells.txt scores.txt hist*.txt medians.txt \
 bad_*_seeds.txt \
 noiseimage_001.cbf mosflm.log dials*log 











